@@ -12,8 +12,8 @@
 
 #define TA_UUID TA_CONCURRENT_LARGE_UUID
 
-#define TA_FLAGS ( TA_FLAG_EXEC_DDR | TA_FLAG_MULTI_SESSION)
-#define TA_STACK_SIZE (2 * 1024)
-#define TA_DATA_SIZE (2 * 1024 * 1024)
+#define TA_FLAGS	0
+#define TA_STACK_SIZE	(2 * 1024)
+#define TA_DATA_SIZE	(2 * 1024 * 1024)
 
 #endif /*USER_TA_HEADER_DEFINES_H*/
