@@ -11,7 +11,7 @@
 
 #define TA_UUID TA_CREATE_FAIL_TEST_UUID
 
-#define TA_FLAGS                    (TA_FLAG_USER_MODE | TA_FLAG_EXEC_DDR)
+#define TA_FLAGS                    0
 #define TA_STACK_SIZE               (1 * 1024)
 #define TA_DATA_SIZE                (32 * 1024)
 
