@@ -11,7 +11,7 @@
 
 #define TA_UUID TA_SUBKEY1_UUID
 
-#define TA_FLAGS	(TA_FLAG_MULTI_SESSION)
+#define TA_FLAGS	0
 #define TA_STACK_SIZE	(2 * 1024)
 #define TA_DATA_SIZE	(2 * 1024)
 
